exceptiontools.MissingTempoError
================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
